---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Describe the steps to reproduce the behavior, including test script.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
 - OS: Windows, Darwin or Linux
 - Running in docker?
 - PyRFC version

**Additional context**
Add any other context about the problem here.
